@@ -18,7 +18,7 @@ logging.basicConfig(
     datefmt="[%X]",
     handlers=[RichHandler(console=Console(stderr=True))],
 )
-log = logging.getLogger("rich")
+log = logging.getLogger("preservation-database")
 log.setLevel(logging.INFO)
 
 sys.path.append(
