@@ -356,6 +356,7 @@ def push_json_to_s3(
     json_obj,
     bucket,
     path,
+    verbose=False,
 ) -> None:
     """
     Writes the JSON data to S3
@@ -363,12 +364,14 @@ def push_json_to_s3(
     :param bucket: the name of the bucket
     :param path: the path of the object to store
     :param json_obj: the JSON to write
+    :param verbose: whether to print status messages
     :return:
     """
     import json
     import logging
 
-    logging.info(f"Writing JSON to S3 bucket {bucket} at path {path}")
+    if verbose:
+        logging.info(f"Writing JSON to S3 bucket {bucket} at path {path}")
 
     obj = s3.Object(bucket, path)
     obj.put(Body=json.dumps(json_obj))
@@ -488,6 +491,10 @@ def rescore_member(
     verbose=False,
     push_to_s3=True,
 ):
+    import environment
+
+    environment.setup_environment(code_bucket, download_settings=False)
+
     import boto3
     import logging
 
@@ -495,10 +502,6 @@ def rescore_member(
     session = boto3.Session()
     s3 = session.resource("s3")
 
-    import environment
-
-    environment.setup_environment(code_bucket, download_settings=False)
-
     try:
         preservations = get_annotation(
             s3client=s3client,
@@ -525,9 +528,11 @@ def rescore_member(
 
         key = f"{annotation_path}/members/{member_id}/{annotation_filename}"
 
-        logging.info(
-            f"Rescoring member {member_id} as {preservations['member-grade']}"
-        )
+        if verbose:
+            logging.info(
+                f"Rescoring member {member_id} as "
+                f"{preservations['member-grade']}"
+            )
 
         if push_to_s3:
             push_json_to_s3(
